==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/da/activity-stream-strings.js <==
// Note - this is a generated da file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nyt faneblad",
  "header_top_sites": "Mest besøgte websider",
  "header_highlights": "Fremhævede",
  "header_recommended_by": "Anbefalet af {provider}",
  "context_menu_button_sr": "Åbn genvejsmenuen for {title}",
  "section_context_menu_button_sr": "Åbn genvejsmenuen afsnit",
  "type_label_visited": "Besøgt",
  "type_label_bookmarked": "Bogmærket",
  "type_label_recommended": "Populært",
  "type_label_pocket": "Gemt til Pocket",
  "type_label_downloaded": "Hentet",
  "menu_action_bookmark": "Bogmærk",
  "menu_action_remove_bookmark": "Fjern bogmærke",
  "menu_action_open_new_window": "Åbn i et nyt vindue",
  "menu_action_open_private_window": "Åbn i et nyt privat vindue",
  "menu_action_dismiss": "Afvis",
  "menu_action_delete": "Slet fra historik",
  "menu_action_pin": "Fastgør",
  "menu_action_unpin": "Frigør",
  "confirm_history_delete_p1": "Er du sikker på, at du vil slette alle forekomster af denne side fra din historik?",
  "confirm_history_delete_notice_p2": "Denne handling kan ikke fortrydes.",
  "menu_action_save_to_pocket": "Gem til Pocket",
  "menu_action_delete_pocket": "Slet fra Pocket",
  "menu_action_archive_pocket": "Arkiver i Pocket",
  "menu_action_show_file_mac_os": "Vis i Finder",
  "menu_action_show_file_windows": "Åbn hentningsmappe",
  "menu_action_show_file_linux": "Åbn hentningsmappe",
  "menu_action_show_file_default": "Vis fil",
  "menu_action_open_file": "Åbn fil",
  "menu_action_copy_download_link": "Kopier linkadresse",
  "menu_action_go_to_download_page": "Gå til siden, filen blev hentet fra",
  "menu_action_remove_download": "Fjern fra historik",
  "search_button": "Søg",
  "search_header": "{search_engine_name}-søgning",
  "search_web_placeholder": "Søg på internettet",
  "section_disclaimer_topstories": "De mest interessante historier på nettet, udvalgt på baggrund af det, du læser. Fra Pocket, nu en del af Mozilla.",
  "section_disclaimer_topstories_linktext": "Læs hvordan det fungerer.",
  "section_disclaimer_topstories_buttontext": "Ok, forstået",
  "prefs_home_header": "Indhold på Firefox' startside",
  "prefs_home_description": "Vælg det indhold, du vil have vist på din startside i Firefox.",
  "prefs_section_rows_option": "{num} række;{num} rækker",
  "prefs_search_header": "Søgning på internettet",
  "prefs_topsites_description": "Mest besøgte websider",
  "prefs_topstories_description2": "Spændende indhold fra nettet, specielt udvalgt til dig",
  "prefs_topstories_options_sponsored_label": "Sponsorerede historier",
  "prefs_topstories_sponsored_learn_more": "Læs mere",
  "prefs_highlights_description": "Et afsnit med sider, du har gemt eller besøgt",
  "prefs_highlights_options_visited_label": "Besøgte sider",
  "prefs_highlights_options_download_label": "Seneste filhentninger",
  "prefs_highlights_options_pocket_label": "Sider gemt til Pocket",
  "prefs_snippets_description": "Nyheder fra Mozilla og Firefox",
  "settings_pane_button_label": "Tilpas siden Nyt faneblad",
  "settings_pane_topsites_header": "Mest besøgte websider",
  "settings_pane_highlights_header": "Fremhævede",
  "settings_pane_highlights_options_bookmarks": "Bogmærker",
  "settings_pane_snippets_header": "Notitser",
  "edit_topsites_button_text": "Rediger",
  "edit_topsites_edit_button": "Rediger denne webside",
  "topsites_form_add_header": "Ny webside",
  "topsites_form_edit_header": "Rediger mest besøgte webside",
  "topsites_form_title_label": "Titel",
  "topsites_form_title_placeholder": "Indtast en titel",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL til selvvalgt billede",
  "topsites_form_url_placeholder": "Indtast eller indsæt en URL",
  "topsites_form_use_image_link": "Brug selvvalgt billede…",
  "topsites_form_preview_button": "Vis prøve",
  "topsites_form_add_button": "Tilføj",
  "topsites_form_save_button": "Gem",
  "topsites_form_cancel_button": "Annuller",
  "topsites_form_url_validation": "Gyldig URL påkrævet",
  "topsites_form_image_validation": "Kunne ikke indlæse billede. Prøv en anden URL.",
  "pocket_read_more": "Populære emner:",
  "pocket_read_even_more": "Se flere historier",
  "highlights_empty_state": "Gå i gang med at browse, så vil vi vise dig nogle af de artikler, videoer og andre sider, du har besøgt eller gemt et bogmærke til for nylig.",
  "topstories_empty_state": "Der er ikke flere nye historier. Kom tilbage senere for at se flere tophistorier fra {provider}. Kan du ikke vente? Vælg et populært emne og find flere spændende historier fra hele verden.",
  "manual_migration_explanation2": "Prøv Firefox med bogmærkerne, historikken og adgangskoderne fra en anden browser.",
  "manual_migration_cancel_button": "Nej tak",
  "manual_migration_import_button": "Importer nu",
  "error_fallback_default_info": "Hovsa. Noget gik galt ved indlæsning af indholdet.",
  "error_fallback_default_refresh_suggestion": "Genindlæs siden og prøv igen.",
  "section_menu_action_remove_section": "Fjern afsnit",
  "section_menu_action_collapse_section": "Sammenfold afsnit",
  "section_menu_action_expand_section": "Udvid afsnit",
  "section_menu_action_manage_section": "Håndter afsnit",
  "section_menu_action_add_topsite": "Tilføj ny webside",
  "section_menu_action_move_up": "Flyt op",
  "section_menu_action_move_down": "Flyt ned",
  "section_menu_action_privacy_notice": "Privatlivspolitik",
  "prefs_restore_defaults_button": "Gendan standarder",
  "settings_pane_header": "Indstillinger for Nyt faneblad",
  "settings_pane_body2": "Vælg, hvad du vil se på denne side.",
  "settings_pane_search_header": "Søgning",
  "settings_pane_search_body": "Søg på nettet fra Nyt faneblad.",
  "settings_pane_topsites_body": "Adgang til de websider, du besøger oftest.",
  "settings_pane_topsites_options_showmore": "Vis to rækker",
  "settings_pane_highlights_body2": "Find tilbage til interessant indhold, du har besøgt eller gemt et bogmærke til for nylig.",
  "settings_pane_highlights_options_visited": "Besøgte websider",
  "settings_pane_snippets_body": "Læs korte opdateringer fra Mozilla om Firefox, internet-kultur og lidt underholdning fra tid til anden.",
  "settings_pane_done_button": "Færdig",
  "settings_pane_topstories_options_sponsored": "Vis sponsorerede historier",
  "pocket_description": "Opdag indhold af høj kvalitet, som du måske ellers ikke ville have opdaget. Indholdet kommer fra Pocket, der nu er en del af Mozilla."
};

==> firefox-62.0b18.source.tar.xz: firefox-62.0/browser/extensions/activity-stream/prerendered/locales/da/activity-stream-strings.js <==
// Note - this is a generated da file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nyt faneblad",
  "header_top_sites": "Mest besøgte websider",
  "header_highlights": "Fremhævede",
  "header_recommended_by": "Anbefalet af {provider}",
  "context_menu_button_sr": "Åbn genvejsmenuen for {title}",
  "section_context_menu_button_sr": "Åbn genvejsmenuen afsnit",
  "type_label_visited": "Besøgt",
  "type_label_bookmarked": "Bogmærket",
  "type_label_recommended": "Populært",
  "type_label_pocket": "Gemt til Pocket",
  "type_label_downloaded": "Hentet",
  "menu_action_bookmark": "Bogmærk",
  "menu_action_remove_bookmark": "Fjern bogmærke",
  "menu_action_open_new_window": "Åbn i et nyt vindue",
  "menu_action_open_private_window": "Åbn i et nyt privat vindue",
  "menu_action_dismiss": "Afvis",
  "menu_action_delete": "Slet fra historik",
  "menu_action_pin": "Fastgør",
  "menu_action_unpin": "Frigør",
  "confirm_history_delete_p1": "Er du sikker på, at du vil slette alle forekomster af denne side fra din historik?",
  "confirm_history_delete_notice_p2": "Denne handling kan ikke fortrydes.",
  "menu_action_save_to_pocket": "Gem til Pocket",
  "menu_action_delete_pocket": "Slet fra Pocket",
  "menu_action_archive_pocket": "Arkiver i Pocket",
  "menu_action_show_file_mac_os": "Vis i Finder",
  "menu_action_show_file_windows": "Åbn hentningsmappe",
  "menu_action_show_file_linux": "Åbn hentningsmappe",
  "menu_action_show_file_default": "Vis fil",
  "menu_action_open_file": "Åbn fil",
  "menu_action_copy_download_link": "Kopier linkadresse",
  "menu_action_go_to_download_page": "Gå til siden, filen blev hentet fra",
  "menu_action_remove_download": "Fjern fra historik",
  "search_button": "Søg",
  "search_header": "{search_engine_name}-søgning",
  "search_web_placeholder": "Søg på internettet",
  "section_disclaimer_topstories": "De mest interessante historier på nettet, udvalgt på baggrund af det, du læser. Fra Pocket, nu en del af Mozilla.",
  "section_disclaimer_topstories_linktext": "Læs hvordan det fungerer.",
  "section_disclaimer_topstories_buttontext": "Ok, forstået",
  "prefs_home_header": "Indhold på Firefox' startside",
  "prefs_home_description": "Vælg det indhold, du vil have vist på din startside i Firefox.",
  "prefs_section_rows_option": "{num} række;{num} rækker",
  "prefs_search_header": "Søgning på internettet",
  "prefs_topsites_description": "Mest besøgte websider",
  "prefs_topstories_description2": "Spændende indhold fra nettet, specielt udvalgt til dig",
  "prefs_topstories_options_sponsored_label": "Sponsorerede historier",
  "prefs_topstories_sponsored_learn_more": "Læs mere",
  "prefs_highlights_description": "Et afsnit med sider, du har gemt eller besøgt",
  "prefs_highlights_options_visited_label": "Besøgte sider",
  "prefs_highlights_options_download_label": "Seneste filhentninger",
  "prefs_highlights_options_pocket_label": "Sider gemt til Pocket",
  "prefs_snippets_description": "Nyheder fra Mozilla og Firefox",
  "settings_pane_button_label": "Tilpas siden Nyt faneblad",
  "settings_pane_topsites_header": "Mest besøgte websider",
  "settings_pane_highlights_header": "Fremhævede",
  "settings_pane_highlights_options_bookmarks": "Bogmærker",
  "settings_pane_snippets_header": "Notitser",
  "edit_topsites_button_text": "Rediger",
  "edit_topsites_edit_button": "Rediger denne webside",
  "topsites_form_add_header": "Ny webside",
  "topsites_form_edit_header": "Rediger mest besøgte webside",
  "topsites_form_title_label": "Titel",
  "topsites_form_title_placeholder": "Indtast en titel",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL til selvvalgt billede",
  "topsites_form_url_placeholder": "Indtast eller indsæt en URL",
  "topsites_form_use_image_link": "Brug selvvalgt billede…",
  "topsites_form_preview_button": "Vis prøve",
  "topsites_form_add_button": "Tilføj",
  "topsites_form_save_button": "Gem",
  "topsites_form_cancel_button": "Annuller",
  "topsites_form_url_validation": "Gyldig URL påkrævet",
  "topsites_form_image_validation": "Kunne ikke indlæse billede. Prøv en anden URL.",
  "pocket_read_more": "Populære emner:",
  "pocket_read_even_more": "Se flere historier",
  "highlights_empty_state": "Gå i gang med at browse, så vil vi vise dig nogle af de artikler, videoer og andre sider, du har besøgt eller gemt et bogmærke til for nylig.",
  "topstories_empty_state": "Der er ikke flere nye historier. Kom tilbage senere for at se flere tophistorier fra {provider}. Kan du ikke vente? Vælg et populært emne og find flere spændende historier fra hele verden.",
  "manual_migration_explanation2": "Prøv Firefox med bogmærkerne, historikken og adgangskoderne fra en anden browser.",
  "manual_migration_cancel_button": "Nej tak",
  "manual_migration_import_button": "Importer nu",
  "error_fallback_default_info": "Hovsa. Noget gik galt ved indlæsning af indholdet.",
  "error_fallback_default_refresh_suggestion": "Prøv igen ved at genindlæse siden.",
  "section_menu_action_remove_section": "Fjern afsnit",
  "section_menu_action_collapse_section": "Sammenfold afsnit",
  "section_menu_action_expand_section": "Udvid afsnit",
  "section_menu_action_manage_section": "Håndter afsnit",
  "section_menu_action_manage_webext": "Håndter udvidelse",
  "section_menu_action_add_topsite": "Tilføj ny webside",
  "section_menu_action_add_search_engine": "Tilføj søgetjeneste",
  "section_menu_action_move_up": "Flyt op",
  "section_menu_action_move_down": "Flyt ned",
  "section_menu_action_privacy_notice": "Privatlivspolitik",
  "firstrun_title": "Tag Firefox med dig",
  "firstrun_content": "Få adgang til din historik, dine bogmærker, adgangskoder og andre indstillinger på alle dine enheder.",
  "firstrun_learn_more_link": "Læs mere om Firefox-konti",
  "firstrun_form_header": "Indtast din mailadresse",
  "firstrun_form_sub_header": "for at fortsætte til Firefox Sync.",
  "firstrun_email_input_placeholder": "Mailadresse",
  "firstrun_invalid_input": "En gyldig mailadresse er påkrævet",
  "firstrun_extra_legal_links": "Ved at fortsætte godkender du vores {terms} og {privacy}.",
  "firstrun_terms_of_service": "tjenestevilkår",
  "firstrun_privacy_notice": "privatlivspolitik",
  "firstrun_continue_to_login": "Fortsæt",
  "firstrun_skip_login": "Spring dette trin over",
  "prefs_restore_defaults_button": "Gendan standarder",
  "settings_pane_header": "Indstillinger for Nyt faneblad",
  "settings_pane_body2": "Vælg, hvad du vil se på denne side.",
  "settings_pane_search_header": "Søgning",
  "settings_pane_search_body": "Søg på nettet fra Nyt faneblad.",
  "settings_pane_topsites_body": "Adgang til de websider, du besøger oftest.",
  "settings_pane_topsites_options_showmore": "Vis to rækker",
  "settings_pane_highlights_body2": "Find tilbage til interessant indhold, du har besøgt eller gemt et bogmærke til for nylig.",
  "settings_pane_highlights_options_visited": "Besøgte websider",
  "settings_pane_snippets_body": "Læs korte opdateringer fra Mozilla om Firefox, internet-kultur og lidt underholdning fra tid til anden.",
  "settings_pane_done_button": "Færdig",
  "settings_pane_topstories_options_sponsored": "Vis sponsorerede historier",
  "pocket_description": "Opdag indhold af høj kvalitet, som du måske ellers ikke ville have opdaget. Indholdet kommer fra Pocket, der nu er en del af Mozilla."
};
